#ifndef NT2_INCLUDE_FUNCTIONS_REVERSE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REVERSE_HPP_INCLUDED

#include <nt2/swar/include/functions/reverse.hpp>

#endif
